Package 'repboxRfun'

Title: Repbox functions called by code injections into R scripts
Description: Try to use as little special dependencies as reasonably possible
Authors: Sebastian Kranz
Maintainer: Sebastian Kranz <[email protected]>
License: What license is it under?
Version: 0.1.0
Built: 2026-05-26 07:35:50 UTC
Source: https://github.com/repboxr/repboxRfun

Help Index